/***************************************************************************
 *
 * Copyright (C) 2008 Felipe Ortiz Cortés.
 *
 * Author: Felipe Ortiz Cortés. <f.ortiz.c@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

#include <QtDBus/QDBusReply>
#include <QtDebug>
#include "dbusacadapter.h"

DBusAcAdapter::DBusAcAdapter() : acIface(NULL)
{
	QDBusReply<QStringList> answer = iface->call("FindDeviceByCapability", "ac_adapter");
	
	if(answer.isValid() && answer.value().size() != 0){
		QDBusConnection conection = QDBusConnection::systemBus();

		acIface = new QDBusInterface("org.freedesktop.Hal", answer.value().at(0),
									"org.freedesktop.Hal.Device", conection);

		acIface->connection().connect("org.freedesktop.Hal", answer.value().at(0),
									"org.freedesktop.Hal.Device", "PropertyModified",
									this, SLOT(showAcStatus(int, QList<QVariant>)));
	}
}

DBusAcAdapter::~DBusAcAdapter()
{
	delete(acIface);
}

bool DBusAcAdapter::getAcState()
{
	QDBusReply<bool> answer = acIface->call("GetProperty", "ac_adapter.present");
	if(!answer.isValid())
		return false;
	return answer.value();
} 

void DBusAcAdapter::showAcStatus(int num, QList<QVariant> list)
{
	for(int i = 0; i < num; i++){
		if(list.at(0).toString().compare("ac_adapter.present") == 0 ){
			emit acStateChanged(getAcState());
		}
	}
}
