/***************************************************************************
 *
 * Copyright (C) 2008 Felipe Ortiz Cortés.
 *
 * Author: Felipe Ortiz Cortés. <f.ortiz.c@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

#include <QtDBus/QDBusReply>
#include <QStringList>
#include "dbusbattery.h"

DBusBattery::DBusBattery() : batIface(NULL)
{
	QDBusReply<QStringList> answer = iface->call("FindDeviceByCapability", "battery");
	
	if(answer.isValid() && answer.value().size() != 0){
		batName = answer.value().at(0);
		iface->connection().connect("org.freedesktop.Hal", "/org/freedesktop/Hal/Manager",
									"org.freedesktop.Hal.Manager", "DeviceRemoved",
									this, SLOT(showBatteryRemove(QString)));

		iface->connection().connect("org.freedesktop.Hal", "/org/freedesktop/Hal/Manager",
									"org.freedesktop.Hal.Manager", "DeviceAdded",
									this, SLOT(showBatteryConnected(QString)));
	
	
		QDBusConnection connection = QDBusConnection::systemBus();
		batIface = new QDBusInterface("org.freedesktop.Hal", batName,
									"org.freedesktop.Hal.Device", connection);
									
		batIface->connection().connect("org.freedesktop.Hal", batName,
									"org.freedesktop.Hal.Device", "PropertyModified",
									this, SLOT(batteryProperties(int, QList<QVariant>)));
	}
	
}

void DBusBattery::batteryProperties(int num, QList<QVariant> list)
{
	for(int i = 0; i < num; i++){
		if(list.at(i).toString().compare("battery.charge_level.percentage") == 0){
			emit chargePercentChanged(getCharge());
		}else if(list.at(i).toString().compare("battery.remaining_time") == 0){
			emit batteryTimeChanged(getRemainingTime());
		}
	}
}

DBusBattery::~DBusBattery()
{
	delete(batIface);
}

void DBusBattery::showBatteryConnected(QString hwName)
{
	if(batName.compare(hwName) == 0)
		emit batteryStateChanged(true);
}

void DBusBattery::showBatteryRemove(QString hwName)
{
	if(batName.compare(hwName) == 0)
		emit batteryStateChanged(false);
}

int DBusBattery::getRemainingTime()
{
	if(batIface){
		QDBusReply<int> answer = batIface->call("GetProperty", "battery.remaining_time");
		if(!answer.isValid())
			return -1;
		return answer.value();
	}
	return -2;
}

int DBusBattery::getCharge()
{
	if(batIface){
		QDBusReply<int> answer = batIface->call("GetProperty", "battery.charge_level.percentage");
		if(!answer.isValid())
			return -1;
		return answer.value();
	}
	return -2;
}

bool DBusBattery::isBatteryConnected()
{
	if(batIface){
		QDBusReply<bool> answer = batIface->call("GetProperty", "battery.present");
		if(!answer.isValid())
			return false;
		return answer.value();
	}
	return false;
}

// QVariant DBusBattery::getProperty(QString property)
// {
// 	if(batIface){
// 		QDBusReply<QVariant> answer = batIface->call("GetProperty", property);
// 		if(!answer.isValid())
// 			return answer.error().message();
// 		return answer.value();
// 	}
// 	return NULL;
// }
