/***************************************************************************
 *
 * Copyright (C) 2008 Felipe Ortiz Cortés.
 *
 * Author: Felipe Ortiz Cortés. <f.ortiz.c@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

#include <QtDBus/QDBusReply>
#include <QStringList>

#include "dbusgovernor.h"

DBusGovernor::DBusGovernor()
{
	QDBusConnection conection = QDBusConnection::systemBus();
	iface = new QDBusInterface("org.freedesktop.Hal", "/org/freedesktop/Hal/devices/computer",
								"org.freedesktop.Hal.Device.CPUFreq", conection);
}

DBusGovernor::~DBusGovernor()
{
	delete(iface);
}

void DBusGovernor::setGovernor(QString governor)
{
	iface->call("SetCPUFreqGovernor", governor);
}

QStringList DBusGovernor::getAvailableGovernors()
{
	QDBusReply<QStringList> answer = iface->call("GetCPUFreqAvailableGovernors");
	if(!answer.isValid())
		return (QStringList)answer.error().message();
	return answer.value();
}

QString DBusGovernor::getCurrentGovernor()
{
	QDBusReply<QString>  answer = iface->call("GetCPUFreqGovernor");

	if(!answer.isValid())
		return answer.error().message();
	return answer.value();
}
