/***************************************************************************
 *
 * Copyright (C) 2008 Felipe Ortiz Cortés.
 *
 * Author: Felipe Ortiz Cortés. <f.ortiz.c@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

#include "menu.h"
#include <QtGui>

Menu::Menu()
{
	dbusPM = new DBusPowerManager();
	dbusGov = new DBusGovernor();

	createActions();
	conectActions();
	addActionsToMenu();
}

void Menu::createActions()
{
	actSuspend = new QAction(tr("Suspend"), this);
	actHibernate = new QAction(tr("Hibernate"), this);
	actDinamic = new QAction(tr("Dynamic"), this);
	actPerformance = new QAction(tr("Performance"), this);
	actPowersave = new QAction(tr("Powersave"), this);
	actRestore = new QAction(tr("Restore"), this);
	actQuit = new QAction(tr("Quit"), this);
}

void Menu::conectActions()
{
	connect(actSuspend, SIGNAL(triggered()), this, SLOT(suspend()));
	connect(actHibernate, SIGNAL(triggered()), this, SLOT(hibernate()));
	connect(actDinamic, SIGNAL(triggered()), this, SLOT(setDinamicGovernor()));
	connect(actPerformance, SIGNAL(triggered()), this, SLOT(setPerformanceGovernor()));
	connect(actPowersave, SIGNAL(triggered()), this, SLOT(setPowersaveGovernor()));
	connect(actRestore, SIGNAL(triggered()), this, SLOT(showNormal()));
	connect(actQuit, SIGNAL(triggered()), qApp, SLOT(quit()));
}

void Menu::addActionsToMenu()
{
	this->addAction(actSuspend);
	this->addAction(actHibernate);
	this->addSeparator();
	this->addAction(actDinamic);
	this->addAction(actPerformance);
	this->addAction(actPowersave);
	this->addSeparator();
	this->addAction(actRestore);
	this->addAction(actQuit);
}

Menu::~Menu()
{
	delete(actDinamic);
	delete(actHibernate);
	delete(actPerformance);
	delete(actPowersave);
	delete(actQuit);
	delete(actRestore);
	delete(actSuspend);
	delete(dbusGov);
	delete(dbusPM);
}

void Menu::suspend()
{
	dbusPM->suspend(0);
}

void Menu::hibernate()
{
	dbusPM->hibernate();
}

void Menu::setDinamicGovernor()
{
	dbusGov->setGovernor("ondemand");
	emit changeGovernor("ondemand");
}

void Menu::setPerformanceGovernor()
{
	dbusGov->setGovernor("performance");
	emit changeGovernor("performance");
}

void Menu::setPowersaveGovernor()
{
	dbusGov->setGovernor("powersave");
	emit changeGovernor("powersave");
}
