/***************************************************************************
 *
 * Copyright (C) 2008 Felipe Ortiz Cortés.
 *
 * Author: Felipe Ortiz Cortés. <f.ortiz.c@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

#include <QtGui>
#include <QIcon>
#include "pm.h"
#include "dbuslaptop.h"

PM::PM()
{
	DBusLaptop dbusLaptop;
	
	if(dbusLaptop.isLaptop()){
		dbusBat = new DBusBattery();
		dbusAc = new DBusAcAdapter();
		createSystrayIcon();
		createConnections();
	}
}

void PM::createConnections()
{
	connect(dbusBat, SIGNAL(chargePercentChanged(int)), this, SLOT(batteryUpdateCharge(int)));
// 	connect(dbusBat, SIGNAL(batteryTimeChanged()), this, SLOT(batteryUpdateTime(int)));
	connect(dbusBat, SIGNAL(batteryStateChanged(bool)), this, SLOT(batteryUpdateState(bool)));

	connect(dbusAc, SIGNAL(acStateChanged(bool)), this, SLOT(acUpdateState(bool)));

	connect(menu, SIGNAL(changeGovernor(QString)), this, SLOT(governorWarning(QString)));
}

void PM::governorWarning(QString governor)
{
	governor.prepend("Change to ");
	governor.append(" mode.");
	systemtray->showMessage(
			tr("Power Manager"),
			tr(governor.toStdString().c_str()),
			QSystemTrayIcon::Information, 1500);
}

void PM::batteryUpdateCharge(int charge)
{
	updateIcon(dbusAc->getAcState(), dbusBat->isBatteryConnected(), charge);
}

void PM::batteryUpdateState(bool state)
{
	updateIcon(dbusAc->getAcState(), state, dbusBat->getCharge());
	if(!state){
		systemtray->showMessage(
				tr("Power Manager"),
				tr("Battery is removed."),
				QSystemTrayIcon::Information, 2000);
	}else{
		systemtray->showMessage(
			tr("Power Manager"),
			tr("Battery is inserted."),
			QSystemTrayIcon::Information, 2000);
	}
}

void PM::acUpdateState(bool state)
{
	updateIcon(state, dbusBat->isBatteryConnected(), dbusBat->getCharge());
}

void PM::createSystrayIcon()
{
	menu = new Menu();
	systemtray = new QSystemTrayIcon(this);	
	updateIcon(dbusAc->getAcState(), dbusBat->isBatteryConnected(), dbusBat->getCharge());
	systemtray->setContextMenu(menu);
	systemtray->show();
}

PM::~PM()
{
	delete(systemtray);
	delete(menu);
	delete(dbusBat);
	delete(dbusAc);
}

void PM::updateIcon(bool ac, bool bat, int charge)
{
	if(bat){
		if(ac){
			switch(charge){
				case 0 ... 9: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-charging-000.png"));
													break;
				case 10 ... 19: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-charging-010.png"));
													break;
				case 20 ... 29: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-charging-020.png"));
													break;
				case 30 ... 39: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-charging-030.png"));
													break;
				case 40 ... 49: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-charging-040.png"));
													break;
				case 50 ... 59: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-charging-050.png"));
													break;
				case 60 ... 69: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-charging-060.png"));
													break;
				case 70 ... 89: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-charging-070.png"));
													break;
				case 90 ... 99: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-charging-090.png"));
													break;
				case 100: systemtray->setIcon(QIcon(
											QApplication::applicationDirPath()+
											"/icons/battery-charging-100.png"));
											break;
			}
		}else{
			switch(charge){
				case 0 ... 9: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-000.png"));
													break;
				case 10 ... 19: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-010.png"));
													break;
				case 20 ... 29: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-020.png"));
													break;
				case 30 ... 39: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-030.png"));
													break;
				case 40 ... 49: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-0040.png"));
													break;
				case 50 ... 59: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-050.png"));
													break;
				case 60 ... 69: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-060.png"));
													break;
				case 70 ... 89: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-070.png"));
													break;
				case 90 ... 99: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-090.png"));
													break;
				case 100: systemtray->setIcon(QIcon(
													QApplication::applicationDirPath()+
													"/icons/battery-discharging-100.png"));
													break;
			}
		}
	}else{
		systemtray->setIcon(QIcon(QApplication::applicationDirPath()+"/icons/ac-adapter.png"));
	}
}
